<?php

namespace BookneticAddon\MolliePaymentGateway;

use BookneticApp\Providers\Helpers\Helper;
use BookneticApp\Providers\Common\PaymentGatewayService;

use function BookneticAddon\MolliePaymentGateway\bkntc__;

class Listener
{

    public static function saveSettings ( $response )
    {
        $mollie_api_key = Helper::_post( 'mollie_api_key', '', 'string' );
        $useSelectedPaymentMethods = Helper::_post( 'use_selected_payment_methods', 0, 'num' );
        $selectedPaymentMethods = Helper::_post( 'selected_payment_methods', [], 'json' );
        $billingCountry = Helper::_post( 'billing_country', '', 'string' );

        if ( $billingCountry )
        {
            Helper::setOption( 'mollie_billing_country', $billingCountry );
            Helper::setOption( 'mollie_use_selected_payment_methods', $useSelectedPaymentMethods );
            Helper::setOption( 'mollie_selected_payment_methods', $selectedPaymentMethods );
        }
        else if ( Helper::getOption( 'mollie_use_selected_payment_methods' ) !== null )
        {
            Helper::setOption( 'mollie_use_selected_payment_methods', $useSelectedPaymentMethods );
        }

        if ( PaymentGatewayService::find( 'mollie' )->isEnabled() && empty( $mollie_api_key ) )
        {
            return Helper::response( false, bkntc__( 'Please, fill all fields to enable Mollie payment gateway!' ), true );
        }

        Helper::setOption( 'mollie_api_key', $mollie_api_key );

        return $response;
    }

    public static function checkMollieCallback ()
    {
        $isMollieRedirect = Helper::_get( 'bkntc_mollie_redirect', false, 'num' );
        $paymentId        = Helper::_get( 'paymentId', '', 'string' );
        $type             = Helper::_get( 'type', '', 'string' );

        if ( empty( $isMollieRedirect ) || empty( $paymentId ) )
            return;

        $mollie     = new Mollie();
        $paymentInf = $mollie->check( $paymentId );

        if ( empty( $paymentInf ) || !isset( $paymentInf->metadata ) || !isset( $paymentInf->metadata->payment_id ) )
            return;

        if ( in_array( $paymentInf->status, [ 'paid', 'authorised', 'authorized' ] ) )
        {
            if ( $type === 'create_payment_link' )
            {
                $appointmentIds = explode( ',', base64_decode( $paymentInf->metadata->payment_id ) );
                $amountTotal    = $paymentInf->amount->value;
                foreach ( $appointmentIds as $appointmentId )
                {
                    PaymentGatewayService::confirmPaymentLink( $appointmentId, $amountTotal, 'mollie' );
                }

                $thanksYouPage = Helper::getOption( 'redirect_url_after_booking', '' );
                $redirectUrl   = empty( $thanksYouPage ) ? site_url() : $thanksYouPage;
                echo '<script>if(window.opener!==null){window.opener.bookneticPaymentStatus( true )}window.location.href = "' . $redirectUrl . '"</script>';
            }
            else
            {
                PaymentGatewayService::confirmPayment( $paymentInf->metadata->payment_id );
                echo '<script>window.opener.bookneticPaymentStatus( true );</script>';
            }

        }
        else if ( in_array( $paymentInf->status, [ 'canceled', 'cancelled', 'failed', 'expired' ] ) )
        {
            if ( $type !== 'create_payment_link' )
            {
                PaymentGatewayService::cancelPayment( $paymentInf->metadata->payment_id );
            }
            echo '<script>if(window.opener!==null){window.opener.bookneticPaymentStatus( false )}window.location.href = "' . site_url() . '"</script>';
        }
        exit;
    }

}
