<?php

namespace BookneticAddon\MolliePaymentGateway;

use BookneticApp\Providers\Core\AddonLoader;
use BookneticApp\Providers\Core\Capabilities;
use BookneticApp\Providers\Core\Route;
use BookneticApp\Providers\Helpers\Helper;
use BookneticApp\Providers\UI\TabUI;
use Mollie\Api\MollieApiClient;
use \Mollie\Api\Resources\BaseCollection;
use \Mollie\Api\Resources\MethodCollection;

function bkntc__($text, $params = [], $esc = true )
{
    return \bkntc__( $text, $params, $esc, MollieAddon::getAddonSlug() );
}

class MollieAddon extends AddonLoader
{

    public function init()
    {
	    Capabilities::registerTenantCapability( 'mollie', bkntc__('Mollie integration') );

	    if( ! Capabilities::tenantCan( 'mollie' ) )
		    return;

        Capabilities::register('mollie_settings' , bkntc__('Mollie settings') , 'settings');

	    Mollie::load();
    }

    public function initBackend()
    {
	    if( ! Capabilities::tenantCan( 'mollie' ) )
		    return;

        Route::post( 'mollie', Backend\Ajax::class );

        if( Capabilities::userCan('mollie_settings') )
        {
            TabUI::get('payment_gateways_settings')
                ->item('mollie')
                ->setTitle('Mollie')
                ->addView( __DIR__ . '/Backend/view/settings.php', [ self::class, 'getPaymentMethods' ] );

            add_filter( 'bkntc_after_request_settings_save_payment_gateways_settings',  [ Listener::class , 'saveSettings' ]);
            add_action( 'bkntc_enqueue_assets', [ self::class, 'enqueueAssets' ], 10, 2 );
        }
    }

    public function initFrontend()
    {
	    if( ! Capabilities::tenantCan( 'mollie' ) )
		    return;

        add_action('bkntc_after_booking_panel_shortcode', function ()
        {
            wp_enqueue_script( 'booknetic-mollie-init', self::loadAsset('assets/frontend/js/init.js' ), [ 'booknetic' ] );
        });

        add_action('bkntc_after_customer_panel_shortcode', function ()
        {
            wp_enqueue_script( 'booknetic-mollie-init', self::loadAsset('assets/frontend/js/init.js' ), [ 'booknetic-cp' ] );
        });

        Listener::checkMollieCallback();

        add_filter( 'bkntc_add_files_through_ajax', [ self::class, 'addFilesThroughAjax' ] );
    }

	public static function enqueueAssets ( $module, $action )
	{
		if( $module == 'settings' && $action == 'payment_gateways_settings' )
		{
			echo '<script type="application/javascript" src="' . self::loadAsset('assets/backend/js/mollie-settings.js' ) . '"></script>';
            echo '<link rel="stylesheet" href="' . self::loadAsset('assets/backend/css/settings.css') . 'type="text/css">';
		}
	}

    public static function addFilesThroughAjax ( $result )
    {
        $result[ 'files' ][] = [
            'type' => 'js',
            'src'  => self::loadAsset( 'assets/frontend/js/init.js' ),
            'id'   => 'booknetic-mollie-init',
        ];

        return $result;
    }

    /**
     * @param BaseCollection|MethodCollection $methods
     */
    private static function structureMethods( $methods ) : array
    {
        $structuredMethods = [];

        foreach ( $methods as $method )
        {
            if ( $method->status == null ) continue;

            $structuredMethods[] = [
                'id'          => $method->id,
                'description' => $method->description,
                'image'       => $method->image->svg,
            ];
        }

        return $structuredMethods;
    }

    public static function initMollieApiClient() : MollieApiClient
    {
        $apiKey = Helper::getOption('mollie_api_key', '' );
        $mollie = new MollieApiClient();

        try
        {
            $mollie->setApiKey( $apiKey );
        } catch ( \Exception $ex ) {}

        return $mollie;
    }

    public static function filterMethods( string $currency, string $billingCountry ) : array
    {
        $mollie = self::initMollieApiClient();

        try
        {
            $filteredOrderMethods = $mollie->methods->allActive( [
                'resource' => 'orders',
                'billingCountry' => $billingCountry,
                'amount' => ( object )
                [
                    'currency' => $currency,
                    'value' => '50.00' // minimum amount for in3 payment gateway
                ]
            ] );
        }
        catch( \Exception $ex )
        {
            return [];
        }

        return self::structureMethods( $filteredOrderMethods );
    }

    public static function getPaymentMethods() : array
    {

        $paymentMethods = self::filterMethods(
                Helper::getOption( 'currency', 'USD' ),
                Helper::getOption( 'mollie_billing_country', '' ) );

        return [
            'all-payment-methods' => $paymentMethods,
            'selected-payment-methods' => Helper::getOption( 'mollie_selected_payment_methods', [] )
        ];
    }
}
