<?php

namespace BookneticAddon\MolliePaymentGateway;

class MollieHelper
{
    public static function getMethodNameById( string $id ) : string
    {
        switch ( $id )
        {
            case 'ideal':          return 'iDEAL';
            case 'creditcard':     return 'Cards';
            case 'in3':            return 'in3';
            case 'klarnapaylater': return 'Klarna Pay later';
            case 'klarnapaynow':   return 'Klarna Pay now.';
            case 'klarnasliceit':  return 'Klarna Slice it';
            case 'paypal':         return 'PayPal';
            case 'banktransfer':   return 'SEPA Bank Transfer';
            case 'sofort':         return 'SOFORT Banking';
            case 'giftcard':       return 'Gift card';
            case 'bancontact':     return 'Bancontact';
            case 'eps':            return 'EPS';
            case 'giropay':        return 'Giropay';
            case 'przelewy24':     return 'Przelewy24';
            case 'kbc':            return 'KBC/CBC Payment Button';
            case 'belfius':        return 'Belfius Direct Net';
            default:               return $id;
        }
    }

    public static function getAllBillingCountries() : array
    {
        return [
            'AD' => ['id' => 'AD', 'text' => 'Andorra'],
            'AE' => ['id' => 'AE', 'text' => 'United Arab Emirates'],
            'AF' => ['id' => 'AF', 'text' => 'Afghanistan'],
            'AG' => ['id' => 'AG', 'text' => 'Antigua and Barbuda'],
            'AI' => ['id' => 'AI', 'text' => 'Anguilla'],
            'AL' => ['id' => 'AL', 'text' => 'Albania'],
            'AM' => ['id' => 'AM', 'text' => 'Armenia'],
            'AO' => ['id' => 'AO', 'text' => 'Angola'],
            'AQ' => ['id' => 'AQ', 'text' => 'Antarctica'],
            'AR' => ['id' => 'AR', 'text' => 'Argentina'],
            'AS' => ['id' => 'AS', 'text' => 'American Samoa'],
            'AT' => ['id' => 'AT', 'text' => 'Austria'],
            'AU' => ['id' => 'AU', 'text' => 'Australia'],
            'AW' => ['id' => 'AW', 'text' => 'Aruba'],
            'AX' => ['id' => 'AX', 'text' => 'Åland Islands'],
            'AZ' => ['id' => 'AZ', 'text' => 'Azerbaijan'],
            'BA' => ['id' => 'BA', 'text' => 'Bosnia and Herzegovina'],
            'BB' => ['id' => 'BB', 'text' => 'Barbados'],
            'BD' => ['id' => 'BD', 'text' => 'Bangladesh'],
            'BE' => ['id' => 'BE', 'text' => 'Belgium'],
            'BF' => ['id' => 'BF', 'text' => 'Burkina Faso'],
            'BG' => ['id' => 'BG', 'text' => 'Bulgaria'],
            'BH' => ['id' => 'BH', 'text' => 'Bahrain'],
            'BI' => ['id' => 'BI', 'text' => 'Burundi'],
            'BJ' => ['id' => 'BJ', 'text' => 'Benin'],
            'BL' => ['id' => 'BL', 'text' => 'Saint Barthélemy'],
            'BM' => ['id' => 'BM', 'text' => 'Bermuda'],
            'BN' => ['id' => 'BN', 'text' => 'Brunei Darussalam'],
            'BO' => ['id' => 'BO', 'text' => 'Bolivia'],
            'BQ' => ['id' => 'BQ', 'text' => 'Bonaire, Sint Eustatius and Saba'],
            'BR' => ['id' => 'BR', 'text' => 'Brazil'],
            'BS' => ['id' => 'BS', 'text' => 'Bahamas'],
            'BT' => ['id' => 'BT', 'text' => 'Bhutan'],
            'BV' => ['id' => 'BV', 'text' => 'Bouvet Island'],
            'BW' => ['id' => 'BW', 'text' => 'Botswana'],
            'BY' => ['id' => 'BY', 'text' => 'Belarus'],
            'BZ' => ['id' => 'BZ', 'text' => 'Belize'],
            'CA' => ['id' => 'CA', 'text' => 'Canada'],
            'CC' => ['id' => 'CC', 'text' => 'Cocos (Keeling) Islands'],
            'CD' => ['id' => 'CD', 'text' => 'The Democratic Republic of the Congo'],
            'CF' => ['id' => 'CF', 'text' => 'Central African Republic'],
            'CG' => ['id' => 'CG', 'text' => 'Congo'],
            'CH' => ['id' => 'CH', 'text' => 'Switzerland'],
            'CI' => ['id' => 'CI', 'text' => 'Côte d\'Ivoire'],
            'CK' => ['id' => 'CK', 'text' => 'Cook Islands'],
            'CL' => ['id' => 'CL', 'text' => 'Chile'],
            'CM' => ['id' => 'CM', 'text' => 'Cameroon'],
            'CN' => ['id' => 'CN', 'text' => 'China'],
            'CO' => ['id' => 'CO', 'text' => 'Colombia'],
            'CR' => ['id' => 'CR', 'text' => 'Costa Rica'],
            'CU' => ['id' => 'CU', 'text' => 'Cuba'],
            'CV' => ['id' => 'CV', 'text' => 'Cabo Verde; Cape Verde'],
            'CW' => ['id' => 'CW', 'text' => 'Curaçao'],
            'CX' => ['id' => 'CX', 'text' => 'Christmas Island'],
            'CY' => ['id' => 'CY', 'text' => 'Cyprus'],
            'CZ' => ['id' => 'CZ', 'text' => 'Czech Republic'],
            'DE' => ['id' => 'DE', 'text' => 'Germany'],
            'DJ' => ['id' => 'DJ', 'text' => 'Djibouti'],
            'DK' => ['id' => 'DK', 'text' => 'Denmark'],
            'DM' => ['id' => 'DM', 'text' => 'Dominica'],
            'DO' => ['id' => 'DO', 'text' => 'Dominican Republic'],
            'DZ' => ['id' => 'DZ', 'text' => 'Algeria'],
            'EC' => ['id' => 'EC', 'text' => 'Ecuador'],
            'EE' => ['id' => 'EE', 'text' => 'Estonia'],
            'EG' => ['id' => 'EG', 'text' => 'Egypt'],
            'EH' => ['id' => 'EH', 'text' => 'Western Sahara'],
            'ER' => ['id' => 'ER', 'text' => 'Eritrea'],
            'ES' => ['id' => 'ES', 'text' => 'Spain'],
            'ET' => ['id' => 'ET', 'text' => 'Ethiopia'],
            'FI' => ['id' => 'FI', 'text' => 'Finland'],
            'FJ' => ['id' => 'FJ', 'text' => 'Fiji'],
            'FK' => ['id' => 'FK', 'text' => 'Falkland Islands (Malvinas)'],
            'FM' => ['id' => 'FM', 'text' => 'Federated States of Micronesia'],
            'FO' => ['id' => 'FO', 'text' => 'Faroe Islands'],
            'FR' => ['id' => 'FR', 'text' => 'France'],
            'GA' => ['id' => 'GA', 'text' => 'Gabon'],
            'GB' => ['id' => 'GB', 'text' => 'United Kingdom'],
            'GD' => ['id' => 'GD', 'text' => 'Grenada'],
            'GE' => ['id' => 'GE', 'text' => 'Georgia'],
            'GF' => ['id' => 'GF', 'text' => 'French Guiana'],
            'GG' => ['id' => 'GG', 'text' => 'Guernsey'],
            'GH' => ['id' => 'GH', 'text' => 'Ghana'],
            'GI' => ['id' => 'GI', 'text' => 'Gibraltar'],
            'GL' => ['id' => 'GL', 'text' => 'Greenland'],
            'GM' => ['id' => 'GM', 'text' => 'Gambia'],
            'GN' => ['id' => 'GN', 'text' => 'Guinea'],
            'GP' => ['id' => 'GP', 'text' => 'Guadeloupe'],
            'GQ' => ['id' => 'GQ', 'text' => 'Equatorial Guinea'],
            'GR' => ['id' => 'GR', 'text' => 'Greece'],
            'GS' => ['id' => 'GS', 'text' => 'South Georgia and the South Sandwich Islands'],
            'GT' => ['id' => 'GT', 'text' => 'Guatemala'],
            'GU' => ['id' => 'GU', 'text' => 'Guam'],
            'GW' => ['id' => 'GW', 'text' => 'Guinea-Bissau'],
            'GY' => ['id' => 'GY', 'text' => 'Guyana'],
            'HK' => ['id' => 'HK', 'text' => 'Hong Kong'],
            'HM' => ['id' => 'HM', 'text' => 'Heard Island and McDonald Islands'],
            'HN' => ['id' => 'HN', 'text' => 'Honduras'],
            'HR' => ['id' => 'HR', 'text' => 'Croatia'],
            'HT' => ['id' => 'HT', 'text' => 'Haiti'],
            'HU' => ['id' => 'HU', 'text' => 'Hungary'],
            'ID' => ['id' => 'ID', 'text' => 'Indonesia'],
            'IE' => ['id' => 'IE', 'text' => 'Ireland'],
            'IL' => ['id' => 'IL', 'text' => 'Israel'],
            'IM' => ['id' => 'IM', 'text' => 'Isle of Man'],
            'IN' => ['id' => 'IN', 'text' => 'India'],
            'IO' => ['id' => 'IO', 'text' => 'British Indian Ocean Territory'],
            'IQ' => ['id' => 'IQ', 'text' => 'Iraq'],
            'IR' => ['id' => 'IR', 'text' => 'Islamic Republic of Iran'],
            'IS' => ['id' => 'IS', 'text' => 'Iceland'],
            'IT' => ['id' => 'IT', 'text' => 'Italy'],
            'JE' => ['id' => 'JE', 'text' => 'Jersey'],
            'JM' => ['id' => 'JM', 'text' => 'Jamaica'],
            'JO' => ['id' => 'JO', 'text' => 'Jordan'],
            'JP' => ['id' => 'JP', 'text' => 'Japan'],
            'KE' => ['id' => 'KE', 'text' => 'Kenya'],
            'KG' => ['id' => 'KG', 'text' => 'Kyrgyzstan'],
            'KH' => ['id' => 'KH', 'text' => 'Cambodia'],
            'KI' => ['id' => 'KI', 'text' => 'Kiribati'],
            'KM' => ['id' => 'KM', 'text' => 'Comoros'],
            'KN' => ['id' => 'KN', 'text' => 'Saint Kitts and Nevis'],
            'KP' => ['id' => 'KP', 'text' => 'Democratic People\'s Republic of Korea'],
            'KR' => ['id' => 'KR', 'text' => 'Republic of Korea'],
            'KW' => ['id' => 'KW', 'text' => 'Kuwait'],
            'KY' => ['id' => 'KY', 'text' => 'Cayman Islands'],
            'KZ' => ['id' => 'KZ', 'text' => 'Kazakhstan'],
            'LA' => ['id' => 'LA', 'text' => 'Lao People\'s Democratic Republic'],
            'LB' => ['id' => 'LB', 'text' => 'Lebanon'],
            'LC' => ['id' => 'LC', 'text' => 'Saint Lucia'],
            'LI' => ['id' => 'LI', 'text' => 'Liechtenstein'],
            'LK' => ['id' => 'LK', 'text' => 'Sri Lanka'],
            'LR' => ['id' => 'LR', 'text' => 'Liberia'],
            'LS' => ['id' => 'LS', 'text' => 'Lesotho'],
            'LT' => ['id' => 'LT', 'text' => 'Lithuania'],
            'LU' => ['id' => 'LU', 'text' => 'Luxembourg'],
            'LV' => ['id' => 'LV', 'text' => 'Latvia'],
            'LY' => ['id' => 'LY', 'text' => 'Libya'],
            'MA' => ['id' => 'MA', 'text' => 'Morocco'],
            'MC' => ['id' => 'MC', 'text' => 'Monaco'],
            'MD' => ['id' => 'MD', 'text' => 'Moldova'],
            'ME' => ['id' => 'ME', 'text' => 'Montenegro'],
            'MF' => ['id' => 'MF', 'text' => 'Saint Martin (French part)'],
            'MG' => ['id' => 'MG', 'text' => 'Madagascar'],
            'MH' => ['id' => 'MH', 'text' => 'Marshall Islands'],
            'MK' => ['id' => 'MK', 'text' => 'The Former Yugoslav Republic of Macedonia'],
            'ML' => ['id' => 'ML', 'text' => 'Mali'],
            'MM' => ['id' => 'MM', 'text' => 'Myanmar'],
            'MN' => ['id' => 'MN', 'text' => 'Mongolia'],
            'MO' => ['id' => 'MO', 'text' => 'Macao'],
            'MP' => ['id' => 'MP', 'text' => 'Northern Mariana Islands'],
            'MQ' => ['id' => 'MQ', 'text' => 'Martinique'],
            'MR' => ['id' => 'MR', 'text' => 'Mauritania'],
            'MS' => ['id' => 'MS', 'text' => 'Montserrat'],
            'MT' => ['id' => 'MT', 'text' => 'Malta'],
            'MU' => ['id' => 'MU', 'text' => 'Mauritius'],
            'MV' => ['id' => 'MV', 'text' => 'Maldives'],
            'MW' => ['id' => 'MW', 'text' => 'Malawi'],
            'MX' => ['id' => 'MX', 'text' => 'Mexico'],
            'MY' => ['id' => 'MY', 'text' => 'Malaysia'],
            'MZ' => ['id' => 'MZ', 'text' => 'Mozambique'],
            'NA' => ['id' => 'NA', 'text' => 'Namibia'],
            'NC' => ['id' => 'NC', 'text' => 'New Caledonia'],
            'NE' => ['id' => 'NE', 'text' => 'Niger'],
            'NF' => ['id' => 'NF', 'text' => 'Norfolk Island'],
            'NG' => ['id' => 'NG', 'text' => 'Nigeria'],
            'NI' => ['id' => 'NI', 'text' => 'Nicaragua'],
            'NL' => ['id' => 'NL', 'text' => 'Netherlands'],
            'NO' => ['id' => 'NO', 'text' => 'Norway'],
            'NP' => ['id' => 'NP', 'text' => 'Nepal'],
            'NR' => ['id' => 'NR', 'text' => 'Nauru'],
            'NU' => ['id' => 'NU', 'text' => 'Niue'],
            'NZ' => ['id' => 'NZ', 'text' => 'New Zealand'],
            'OM' => ['id' => 'OM', 'text' => 'Oman'],
            'PA' => ['id' => 'PA', 'text' => 'Panama'],
            'PE' => ['id' => 'PE', 'text' => 'Peru'],
            'PF' => ['id' => 'PF', 'text' => 'French Polynesia'],
            'PG' => ['id' => 'PG', 'text' => 'Papua New Guinea'],
            'PH' => ['id' => 'PH', 'text' => 'Philippines'],
            'PK' => ['id' => 'PK', 'text' => 'Pakistan'],
            'PL' => ['id' => 'PL', 'text' => 'Poland'],
            'PM' => ['id' => 'PM', 'text' => 'Saint Pierre and Miquelon'],
            'PN' => ['id' => 'PN', 'text' => 'Pitcairn'],
            'PR' => ['id' => 'PR', 'text' => 'Puerto Rico'],
            'PS' => ['id' => 'PS', 'text' => 'State of Palestine'],
            'PT' => ['id' => 'PT', 'text' => 'Portugal'],
            'PW' => ['id' => 'PW', 'text' => 'Palau'],
            'PY' => ['id' => 'PY', 'text' => 'Paraguay'],
            'QA' => ['id' => 'QA', 'text' => 'Qatar'],
            'RE' => ['id' => 'RE', 'text' => 'Réunion'],
            'RO' => ['id' => 'RO', 'text' => 'Romania'],
            'RS' => ['id' => 'RS', 'text' => 'Serbia'],
            'RU' => ['id' => 'RU', 'text' => 'Russian Federation'],
            'RW' => ['id' => 'RW', 'text' => 'Rwanda'],
            'SA' => ['id' => 'SA', 'text' => 'Saudi Arabia'],
            'SB' => ['id' => 'SB', 'text' => 'Solomon Islands'],
            'SC' => ['id' => 'SC', 'text' => 'Seychelles'],
            'SD' => ['id' => 'SD', 'text' => 'Sudan'],
            'SE' => ['id' => 'SE', 'text' => 'Sweden'],
            'SG' => ['id' => 'SG', 'text' => 'Singapore'],
            'SH' => ['id' => 'SH', 'text' => 'Saint Helena, Ascension and Tristan da Cunha'],
            'SI' => ['id' => 'SI', 'text' => 'Slovenia'],
            'SJ' => ['id' => 'SJ', 'text' => 'Svalbard and Jan Mayen'],
            'SK' => ['id' => 'SK', 'text' => 'Slovakia'],
            'SL' => ['id' => 'SL', 'text' => 'Sierra Leone'],
            'SM' => ['id' => 'SM', 'text' => 'San Marino'],
            'SN' => ['id' => 'SN', 'text' => 'Senegal'],
            'SO' => ['id' => 'SO', 'text' => 'Somalia'],
            'SR' => ['id' => 'SR', 'text' => 'Suriname'],
            'SS' => ['id' => 'SS', 'text' => 'South Sudan'],
            'ST' => ['id' => 'ST', 'text' => 'Sao Tome and Principe'],
            'SV' => ['id' => 'SV', 'text' => 'El Salvador'],
            'SX' => ['id' => 'SX', 'text' => 'Sint Maarten (Dutch part)'],
            'SY' => ['id' => 'SY', 'text' => 'Syrian Arab Republic'],
            'SZ' => ['id' => 'SZ', 'text' => 'Swaziland'],
            'TC' => ['id' => 'TC', 'text' => 'Turks and Caicos Islands'],
            'TD' => ['id' => 'TD', 'text' => 'Chad'],
            'TF' => ['id' => 'TF', 'text' => 'French Southern Territories'],
            'TG' => ['id' => 'TG', 'text' => 'Togo'],
            'TH' => ['id' => 'TH', 'text' => 'Thailand'],
            'TJ' => ['id' => 'TJ', 'text' => 'Tajikistan'],
            'TK' => ['id' => 'TK', 'text' => 'Tokelau'],
            'TL' => ['id' => 'TL', 'text' => 'Timor-Leste'],
            'TM' => ['id' => 'TM', 'text' => 'Turkmenistan'],
            'TN' => ['id' => 'TN', 'text' => 'Tunisia'],
            'TO' => ['id' => 'TO', 'text' => 'Tonga'],
            'TR' => ['id' => 'TR', 'text' => 'Turkey'],
            'TT' => ['id' => 'TT', 'text' => 'Trinidad and Tobago'],
            'TV' => ['id' => 'TV', 'text' => 'Tuvalu'],
            'TW' => ['id' => 'TW', 'text' => 'Taiwan'],
            'TZ' => ['id' => 'TZ', 'text' => 'United Republic of Tanzania'],
            'UA' => ['id' => 'UA', 'text' => 'Ukraine'],
            'UG' => ['id' => 'UG', 'text' => 'Uganda'],
            'UM' => ['id' => 'UM', 'text' => 'United States Minor Outlying Islands'],
            'US' => ['id' => 'US', 'text' => 'United States'],
            'UY' => ['id' => 'UY', 'text' => 'Uruguay'],
            'UZ' => ['id' => 'UZ', 'text' => 'Uzbekistan'],
            'VA' => ['id' => 'VA', 'text' => 'Holy See (Vatican City State)'],
            'VC' => ['id' => 'VC', 'text' => 'Saint Vincent and the Grenadines'],
            'VE' => ['id' => 'VE', 'text' => 'Venezuela'],
            'VG' => ['id' => 'VG', 'text' => 'British Virgin Islands'],
            'VI' => ['id' => 'VI', 'text' => 'U.S. Virgin Islands'],
            'VN' => ['id' => 'VN', 'text' => 'Viet Nam'],
            'VU' => ['id' => 'VU', 'text' => 'Vanuatu'],
            'WF' => ['id' => 'WF', 'text' => 'Wallis and Futuna'],
            'WS' => ['id' => 'WS', 'text' => 'Samoa'],
            'YE' => ['id' => 'YE', 'text' => 'Yemen'],
            'YT' => ['id' => 'YT', 'text' => 'Mayotte'],
            'ZA' => ['id' => 'ZA', 'text' => 'South Africa'],
            'ZM' => ['id' => 'ZM', 'text' => 'Zambia'],
            'ZW' => ['id' => 'ZW', 'text' => 'Zimbabwe']
        ];
    }
}
