(function ( $ )
{
    'use strict';

    $( document ).ready( function ()
    {
        const billing_country = $( '#billing_country' );

        if ( billing_country.val() )
            $( "#mollie-warning" ).show();

        booknetic.addFilter( 'ajax_settings.save_payment_gateways_settings', function ( params )
        {
            params.append( 'mollie_api_key', $( '#input_mollie_api_key' ).val() );
            params.append( 'use_selected_payment_methods', $( '#enable_specific_methods' ).is(':checked') ? 1 : 0 );

            if ( ! billing_country.val() )
                return params;

            params.append( 'billing_country', billing_country.val() );

            let selected_methods = [];

            $( '#payment-methods .method [ type="checkbox" ]:checked' ).each( function ()
            {
                selected_methods.push( $( this ).next().next().val() );
            });

            params.append( 'selected_payment_methods', JSON.stringify( selected_methods ) );

            return params;
        } );


        billing_country.select2({
            theme: 'bootstrap',
            placeholder: booknetic.__('select'),
            allowClear: true
        });

        $( document ).on( 'click', '#enable_specific_methods', function ()
        {
            if ( $( '#enable_specific_methods' ).is(':checked') )
                $( '#selected-payment-methods' ).show();
            else
                $( '#selected-payment-methods' ).hide();
        }).on( 'change', '#billing_country', function ()
        {
            booknetic.ajax( 'mollie.update_available_methods', { country: $( '#billing_country' ).val() }, function ( response )
            {
                const payment_methods = $( '#payment-methods' );

                payment_methods.empty();

                for ( const payment_method of response[ 'all-payment-methods' ] )
                {
                    let selected = '';
                    const method_id = payment_method[ 'id' ];
                    const method_name = payment_method[ 'name' ];
                    const method_image = payment_method[ 'image' ];
                    const input_id = 'select_payment_method_' + method_id;

                    if ( response[ 'selected-payment-methods' ].includes( method_id ) )
                        selected = 'checked';

                    if ( billing_country.val() )
                        $( "#mollie-warning" ).fadeIn();
                    else
                        $( "#mollie-warning" ). fadeOut();

                    payment_methods.append(
                        $(
                            `<div class='method'>
                                <figure class="method-icon"><img src="${ method_image }"></figure>
                                <span class="method-name">${ method_name }</span>
                                <div class="fs_onoffswitch">
                                    <input type="checkbox" class="bkntc_use_specific_payment_methods fs_onoffswitch-checkbox green_switch" id="${ input_id }" ${ selected }>
                                    <label class="fs_onoffswitch-label" for="${ input_id }"></label>
                                    <input type="hidden" value="${ method_id }">
                                </div>
                            </div>`
                        )
                    );
                }
            });
        });
    } );
} )( jQuery );