<?php

namespace BookneticAddon\SquarePaymentGateway;

use BookneticApp\Providers\Helpers\Helper;
use BookneticApp\Providers\Common\PaymentGatewayService;
use function BookneticAddon\SquarePaymentGateway\bkntc__;

class Listener
{

    public static function saveSettings ( $response )
    {
        $square_access_token = Helper::_post( 'square_access_token', '', 'string' );
        $square_location_id  = Helper::_post( 'square_location_id', '', 'string' );
        $square_mode         = Helper::_post( 'square_mode', 'sandbox', 'string', [ 'sandbox', 'live' ] );

        if ( PaymentGatewayService::find( 'square' )->isEnabled() && ( empty( $square_access_token ) || empty( $square_location_id ) ) )
        {
            return Helper::response( false, bkntc__( 'Please, fill all fields to enable Square payment gateway!' ), true );
        }

        Helper::setOption( 'square_access_token', $square_access_token );
        Helper::setOption( 'square_location_id', $square_location_id );
        Helper::setOption( 'square_mode', $square_mode );

        return $response;
    }

    public static function checkSquareCallback ()
    {
        $bookneticSquareStatus = Helper::_get( 'booknetic_square_status', false, 'string', [ 'success', 'cancel' ] );
        $bookneticPaymentId    = Helper::_get( 'booknetic_payment_id', false, 'string' );
        $orderId               = Helper::_get( 'orderId', '', 'string' );
        $type                  = Helper::_get( 'type', '', 'string' );

        if ( empty( $bookneticSquareStatus ) || empty( $bookneticPaymentId ) ) {
            return;
        }

        $paymentStatus = false;
        if ( $bookneticSquareStatus == 'success' && !empty( $orderId ) )
        {
            $square = new Square();
            $square->setId( $bookneticPaymentId );
            $checkPaymentStatus = $square->check( $orderId );

            if ( $checkPaymentStatus['status'] == true )
            {
                $paymentStatus = true;
            }
        }

        if ( $paymentStatus )
        {
            if ( $type === 'create_payment_link' )
            {

                $appointmentIds = explode( ',', base64_decode( $bookneticPaymentId ) );
                array_pop( $appointmentIds );
                $amountTotal = $checkPaymentStatus['total_money'];
                foreach ( $appointmentIds as $appointmentId )
                {
                    PaymentGatewayService::confirmPaymentLink( $appointmentId, $amountTotal / 100, 'square' );
                }
                $thanksYouPage = Helper::getOption( 'redirect_url_after_booking', '' );
                $redirectUrl   = empty( $thanksYouPage ) ? site_url() : $thanksYouPage;
                echo '<script>if(window.opener!==null){window.opener.bookneticPaymentStatus( true )}window.location.href = "' . $redirectUrl . '"</script>';

            }
            else
            {
                PaymentGatewayService::confirmPayment( $bookneticPaymentId );
                echo '<script>window.opener.bookneticPaymentStatus( true );</script>';
            }

        }
        else
        {
            if ( $type !== 'create_payment_link' )
            {
                PaymentGatewayService::cancelPayment( $bookneticPaymentId );
            }
            echo '<script>if(window.opener!==null){window.opener.bookneticPaymentStatus( false )}window.location.href = "' . site_url() . '"</script>';
        }
        exit;
    }

}
