<?php

namespace BookneticAddon\SquarePaymentGateway;

use BookneticApp\Providers\Core\AddonLoader;
use BookneticApp\Providers\Core\Capabilities;
use BookneticApp\Providers\UI\TabUI;

function bkntc__ ( $text, $params = [], $esc = true )
{
    return \bkntc__( $text, $params, $esc, SquareAddon::getAddonSlug() );
}

class SquareAddon extends AddonLoader
{

    public function init ()
    {
	    Capabilities::registerTenantCapability( 'square', bkntc__('Square integration') );

	    if( ! Capabilities::tenantCan( 'square' ) )
		    return;

        Capabilities::register('square_settings' , bkntc__('Square settings') , 'settings');

		Square::load();
    }

    public function initBackend()
    {
	    if( ! Capabilities::tenantCan( 'square' ) )
		    return;

	    if( Capabilities::userCan('square_settings') )
        {
            TabUI::get('payment_gateways_settings')
                ->item('square')
                ->setTitle('Square')
                ->addView( __DIR__ . '/Backend/view/settings.php' );

            add_filter( 'bkntc_after_request_settings_save_payment_gateways_settings',  [ Listener::class , 'saveSettings' ]);
            add_action( 'bkntc_enqueue_assets', [ self::class, 'enqueueAssets' ], 10, 2 );
        }
    }

    public static function enqueueAssets ( $module, $action )
    {
        if( $module == 'settings' && $action == 'payment_gateways_settings' )
        {
            echo '<script type="application/javascript" src="' . self::loadAsset('assets/backend/js/square-settings.js' ) . '"></script>';
        }
    }

    public function initFrontend()
    {
	    if( ! Capabilities::tenantCan( 'square' ) )
		    return;

	    Listener::checkSquareCallback();

        add_action('bkntc_after_booking_panel_shortcode', function ()
        {
            wp_enqueue_script( 'booknetic-square-init', self::loadAsset('assets/frontend/js/init.js' ), [ 'booknetic' ] );
        });

        add_action('bkntc_after_customer_panel_shortcode', function ()
        {
            wp_enqueue_script( 'booknetic-square-init', self::loadAsset('assets/frontend/js/init.js' ), [ 'booknetic-cp' ] );
        });

        add_filter( 'bkntc_add_files_through_ajax', [ self::class, 'addFilesThroughAjax' ] );
    }

    public static function addFilesThroughAjax ( $result )
    {
        $result[ 'files' ][] = [
            'type' => 'js',
            'src'  => self::loadAsset( 'assets/frontend/js/init.js' ),
            'id'   => 'booknetic-square-init',
        ];

        return $result;
    }
}