<?php

namespace BookneticAddon\WCPaymentGateway;

use BookneticAddon\WCPaymentGateway\Providers\WcMultiTenantHelper;
use BookneticApp\Providers\Helpers\Helper;
use BookneticApp\Providers\Common\PaymentGatewayService;
use BookneticAddon\WCPaymentGateway\Providers\WooCommerceGateway;
use function BookneticAddon\WCPaymentGateway\bkntc__;

class Listener
{

	public static function addParamsToConfirmDetails ( $params )
	{
        if( $params['status'] === 'error' )
            return $params;

		$params[ 'is_woocommerce_enabled' ]         = PaymentGatewayService::find( 'woocommerce' )->isEnabled();
		$params[ 'is_local_payment_enabled' ]       = PaymentGatewayService::find( 'local' )->isEnabled();
		$params[ 'woocommerce_skip_confirmation' ]  = Helper::getOption( 'woocommerce_skip_confirm_step', 'on', false ) === 'on' ? 'on' : 'off';

		return $params;
	}

    public static function saveSettings ( $response )
	{
		if (  PaymentGatewayService::find( 'woocommerce' )->isEnabled() )
		{
            if ( ! class_exists( 'woocommerce' ) )
            {
                return Helper::response( false, [], true );
            }

			// Check Booknetic product. If not exist, create it..
			WooCommerceGateway::bookneticProduct();
		}

		if ( Helper::isSaaSVersion() )
		{
			$wc_payment_gateways_arr    = Helper::_post('wc_payment_gateways', '', 'string');
			$wc_payment_gateways_arr    = json_decode( $wc_payment_gateways_arr, true );
			$wc_payment_gateways_arr    = is_array( $wc_payment_gateways_arr ) ? $wc_payment_gateways_arr : [];

			$wcHelperService = new WcMultiTenantHelper();
			$wcHelperService->startCollectiongUpdatedOptions();

			foreach ( $wc_payment_gateways_arr as $wc_payment_gateway_id => $wc_pg_status )
			{
				$wcHelperService->changePaymentGatewayStatus( $wc_payment_gateway_id, $wc_pg_status );
			}

			$wcHelperService->stopCollectiongUpdatedOptions();
			$wcHelperService->saveCollectedOptions();
		}
		else
		{
			$skipConfirmationStep           = Helper::_post( 'woocommerce_skip_confirm_step', 'on', 'string', [ 'on', 'off' ] );
			$orderDetails                   = Helper::_post( 'woocommerde_order_details', '', 'string' );
			$woocommerceOrderStatuses       = Helper::_post( 'woocommerce_order_statuses', '', 'string' );
			$redirectTo                     = Helper::_post( 'woocommerce_rediret_to', 'cart', 'string', [ 'cart', 'checkout' ] );
            $woocommerceApprovedOrderStatus = Helper::_post('woocommerce_approved_order_status', '', 'string');

            if ( PaymentGatewayService::find( 'woocommerce' )->isEnabled() ) {
                if ( empty( $orderDetails ) ) {
                    return Helper::response( false, bkntc__( 'Please, fill all fields to enable Woocommerce payment gateway!' ), true );
                }

                if ( PaymentGatewayService::find('local')->isEnabled() && $skipConfirmationStep === 'on' ) {
                    return Helper::response( false, bkntc__( 'Skipping confirmation step must be turned off when another payment method enabled!' ), true );
                }
            }

			Helper::setOption( 'woocommerce_skip_confirm_step',     $skipConfirmationStep );
			Helper::setOption( 'woocommerde_order_details',         $orderDetails );
			Helper::setOption( 'woocommerce_rediret_to',            $redirectTo );
			Helper::setOption( 'woocommerce_order_statuses',        $woocommerceOrderStatuses );
			Helper::setOption( 'woocommerce_approved_order_status', $woocommerceApprovedOrderStatus );
		}

		return $response;
	}

}