<?php

namespace BookneticAddon\WCPaymentGateway\Providers;

use BookneticApp\Backend\Appointments\Helpers\AppointmentSmartObject;
use BookneticApp\Backend\Appointments\Helpers\TimeSlotService;
use BookneticApp\Config;
use BookneticApp\Models\Appointment;
use BookneticApp\Providers\Helpers\Helper;
use BookneticApp\Models\AppointmentExtra;
use BookneticApp\Backend\Appointments\Helpers\AppointmentService;

class WcProductObject
{

	private $cartItemKey;
	private $productId;
	private $appointmentId;

	/** @var AppointmentSmartObject */
	public $bookingData;

	public function init ()
	{
		$this->bookingData = AppointmentSmartObject::load( $this->appointmentId );
		$this->checkSelectedTimeslot();
	}

	public function productAdditionalData ()
	{
		$additionalData = '';

		$woocommerdeOrderDetails = Helper::getOption( 'woocommerde_order_details', "Date: {appointment_date}\nTime: {appointment_start_time}\nStaff: {staff_name}", false );
		$woocommerdeOrderDetails = trim( $woocommerdeOrderDetails );

		if ( ! empty( $woocommerdeOrderDetails ) )
		{
			$shortCodeData = [
				'appointment_id'            => $this->bookingData->getId(),
				'service_id'                => $this->bookingData->getInfo()->service_id,
				'staff_id'                  => $this->bookingData->getInfo()->staff_id,
				'customer_id'               => $this->bookingData->getInfo()->customer_id,
				'location_id'               => $this->bookingData->getInfo()->location_id
			];

			$replacedData = Config::getShortCodeService()->replace( strip_tags( $woocommerdeOrderDetails, '<p><br>' ), $shortCodeData );

			$additionalData .= '<div>' . ( $replacedData ) . '</div>';
		}

		return $additionalData;
	}

    public static function productAdditionalDataStatic ( $bookingData )
    {
        $additionalData = '';

        $woocommerdeOrderDetails = Helper::getOption( 'woocommerde_order_details', "Date: {appointment_date}\nTime: {appointment_start_time}\nStaff: {staff_name}", false );
        $woocommerdeOrderDetails = trim( $woocommerdeOrderDetails );

        if ( ! empty( $woocommerdeOrderDetails ) )
        {
            $shortCodeData = [
                'appointment_id'            => $bookingData->getId(),
                'service_id'                => $bookingData->getInfo()->service_id,
                'staff_id'                  => $bookingData->getInfo()->staff_id,
                'customer_id'               => $bookingData->getInfo()->customer_id,
                'location_id'               => $bookingData->getInfo()->location_id
            ];

            $replacedData = Config::getShortCodeService()->replace( strip_tags( $woocommerdeOrderDetails, '<p><br>' ), $shortCodeData );

            $additionalData .= '<div>' . ( nl2br( $replacedData ) ) . '</div>';
        }

        return $additionalData;
    }

	public function isAppointmentExists ()
	{
		$appointmentInf = Appointment::get( $this->appointmentId );

		return $appointmentInf && $appointmentInf->id > 0;
	}

	public function isAppointmentPaid ()
	{
		return $this->bookingData->getInfo()->payment_status === 'paid';
	}

	public function removeAppointment ()
	{
		AppointmentService::deleteAppointment( $this->appointmentId );

		WC()->cart->remove_cart_item( $this->cartItemKey );
		unset( WooCommerceGateway::$cartItems[ $this->productId ] );
	}

	public function setCartItemKey ( $key )
	{
		$this->cartItemKey = $key;
	}

	public function setProductId ( $productId )
	{
		$this->productId = $productId;
	}

	public function setAppointmentId ( $appointmentId )
	{
		$this->appointmentId = $appointmentId;
	}

	/**
	 * Sechilen timeslot 10 deqiqe erzinde statusu waiting_for_payment olur ki, bu muddet erzinde 2-ci user eyni timeslotu seche bilmesin.
	 * Lakin 10 deqiqe sonra avtomatik status cancel olur ve mushteriler artiq bu timeslotu seche bilerler.
	 * Eyni timeslota 2 mushteri rezervasiya etmesinin qarshisini almaq uchun bu metod yaradilib...
	 */
	private function checkSelectedTimeslot ()
	{
		if ( ! empty( $this->bookingData->getInfo() ) )
		{
			if ( $this->bookingData->getInfo()->payment_status !== 'pending' )
			{
				$extras_arr = [];

				foreach ( AppointmentExtra::where('appointment_id', $this->bookingData->getId())->fetchAll() as $extraInf )
				{
					$extras_arr[] = [
						'id'       => $extraInf->extra_id,
						'quantity' => $extraInf->quantity,
						'price'    => $extraInf->price,
						'duration' => $extraInf->duration,
						'customer' => $this->bookingData->getInfo()->customer_id
					];
				}

				$selectedTimeSlotInfo = new TimeSlotService( $this->bookingData->getAppointmentInfo()->date, $this->bookingData->getAppointmentInfo()->start_time );

				$selectedTimeSlotInfo->setStaffId( $this->bookingData->getStaffInf()->id )
				                     ->setServiceId( $this->bookingData->getServiceInf()->id )
				                     ->setServiceExtras( $extras_arr )
				                     ->setExcludeAppointmentId( $this->bookingData->getInfo()->appointment_id )
				                     ->setCalledFromBackEnd( false )
				                     ->setShowExistingTimeSlots( true );

				if ( ! $selectedTimeSlotInfo->isBookable() )
				{
					WooCommerceGateway::emptyCart();
				}
			}
		}
	}

	public function getAppointmentID ()
	{
		return $this->bookingData->getInfo() ? $this->bookingData->getInfo()->id : 0;
	}

}