<?php

namespace BookneticAddon\WCPaymentGateway\Providers;

use BookneticApp\Models\Appointment;
use BookneticAddon\WCPaymentGateway\WcPaymentGatewayAddon;
use BookneticApp\Backend\Appointments\Helpers\AppointmentRequests;
use BookneticApp\Backend\Appointments\Helpers\AppointmentSmartObject;
use BookneticApp\Models\Customer;
use BookneticApp\Providers\DB\DB;
use BookneticAddon\WCPaymentGateway\Providers\WcProductObject;
use BookneticApp\Providers\Helpers\Date;
use BookneticApp\Providers\Helpers\Helper;
use BookneticApp\Providers\Core\Permission;
use BookneticApp\Providers\Common\PaymentGatewayService;
use function BookneticAddon\WCPaymentGateway\bkntc__;

class WooCommerceGateway extends PaymentGatewayService
{

    protected $slug = 'woocommerce';

    private static $twoWaySync = false;

	/**
//	 * @var WcProductObject[]
	 */
	public static $cartItems = [];

	public function __construct()
	{
		$this->setDefaultTitle( Helper::isSaaSVersion() ? bkntc__( 'Other' ) : bkntc__( 'WooCommerce' ) );
		$this->setDefaultIcon( WcPaymentGatewayAddon::loadAsset( 'assets/frontend/icons/card.svg' ) );

        if ( Helper::isSaaSVersion() && isset( $_COOKIE[ 'booknetic_tenant_id' ] ) && is_numeric( $_COOKIE[ 'booknetic_tenant_id' ] ) && ! ( Permission::tenantId() > 0 ) )
        {
            Permission::setTenantId( $_COOKIE[ 'booknetic_tenant_id' ] );
        }

        if ( Helper::isSaaSVersion() && Permission::isSuperAdministrator() && ! ( Permission::tenantId() > 0 ) )
        {
            self::handleActionsAsTenant();
        }

		if ( $this->isEnabled() )
		{
			add_action( 'wp_loaded', [ static::class, 'loadWC' ] );
		}
	}

	public function when( $enabled, $appointmentRequests = null )
	{
		return class_exists( 'woocommerce', false )
		       && (
		            ! Helper::isSaaSVersion()
		            || Helper::getOption('allow_to_use_woocommerce_integration', 'off', false) === 'on'
		       )
		       && $enabled;
	}

    /**
     * @param AppointmentRequests $appointmentRequests
     * @return object
     */
    public function doPayment ( $appointmentRequests )
	{
        WC()->cart->empty_cart();

        foreach ( $appointmentRequests->appointments as $appointmentObj )
        {
            self::addToCart( $appointmentObj );
        }

		return ( object ) [
			'status' => true,
			'data'   => [ 'woocommerce_cart_url' => self::redirect() ]
		];
	}

	public static function loadWC ( )
	{
        if ( ! WC()->cart )
        {
            wc_load_cart();
        }

        $cartItems = WC()->cart ? WC()->cart->get_cart() : [];

        if ( Helper::isSaaSVersion() )
        {
            foreach ( $cartItems as $itemKey => $item )
            {
                if ( empty( $item [ 'booknetic_billing_id' ] ) )
                    continue;
                else
                    return;
            }

            // doit burda 1 conflict yaranir. Bezi pluginler init run olmamish ozunun optionlarini chekib cache edib saxlayirlar.
            // Bizim addonlar/pluginler ise normal olaraq init`in ichinde ishe dushurler ver get_options() uchun filter apply edirler...
            // Neticede bizim funksiya gec ishe dushur deye value sehv alinir. Numune: "Paypal plus" pluginin.
            // Bu ashagidaki kodu init-den chole qaldira bilerik, o halda da tenant_id set etmekde sorunlar yaranir. User login olub ya yox check etmek olmur deyene. Chunki orda hele hech WP-nin komponentleri bele load olmayiblar...
            WcMultiTenantHelper::getInstance()->startReplacingNecessaryOptions();
        }

		foreach ( $cartItems as $itemKey => $item )
		{
			if ( empty( $item[ 'booknetic_appointment_id' ] ) )
				continue;

			$wcService = new WcProductObject();

			$wcService->setCartItemKey( $itemKey );
			$wcService->setProductId( $item[ 'product_id' ] );
			$wcService->setAppointmentId( $item[ 'booknetic_appointment_id' ] );
			$wcService->init();

			if( $wcService->isAppointmentExists() )
			{
				self::$cartItems[ $item[ 'booknetic_appointment_id' ] ] = $wcService;
			}
		}

		self::setClientTimezone( $cartItems );
		self::initFilters();
	}

	private static function initFilters ()
	{
		$productId = self::bookneticProduct();

		add_filter( 'woocommerce_get_item_data',            [ self::class, 'getItemData' ], 10, 2 );
		add_filter( 'woocommerce_cart_item_name',           [ self::class, 'getItemName' ], 10, 2 );

		add_filter( 'woocommerce_cart_item_thumbnail',      [ self::class, 'getItemImage' ], 10, 3 );
		add_filter( 'woocommerce_cart_item_price',          [ self::class, 'getItemPrice' ], 10, 3 );
		add_action( 'woocommerce_before_calculate_totals',  [ self::class, 'beforeCalculateTotals' ], 10, 1 );

		if ( ! is_wp_error( wp_set_post_terms( $productId, ['exclude-from-search', 'exclude-from-catalog'], 'product_visibility', false ) ) )
		{
			do_action( 'woocommerce_product_set_visibility', $productId, "hidden" );
		}

		add_action( 'woocommerce_checkout_create_order_line_item', [ self::class, 'checkoutCreateOrderLineItem' ], 10, 4 );

		add_action( 'woocommerce_remove_cart_item',             [ self::class, 'removeCartItem' ], 10, 2 );
		add_filter( 'woocommerce_checkout_get_value',           [ self::class, 'checkoutFields' ], 10, 2 );

		add_action( 'woocommerce_order_status_changed',         [ self::class, 'orderStatusChanged' ], 10, 3 );
        add_filter( 'woocommerce_order_item_name',              [self::class, 'thankYouPageItemName'], 10, 3 );

		add_filter( 'woocommerce_checkout_cart_item_quantity',  [ self::class, 'checkoutCartItemQuantity' ], 10, 2 );
		add_filter( 'woocommerce_order_item_quantity_html',     [ self::class, 'checkoutCartItemQuantity' ], 10, 2 );


		add_filter( 'woocommerce_display_item_meta',            [ self::class, 'displayItemMeta' ], 10, 3 );

		add_filter('woocommerce_thankyou_order_id', function ( $order_id )
		{
			add_filter( 'woocommerce_order_item_name',          [self::class, 'thankYouPageItemName'], 10, 2);
			return $order_id;
		});

		add_action( 'woocommerce_before_order_itemmeta',          [ self::class, 'addDynamicMetaData' ], 10, 1 );
		add_action( 'woocommerce_order_item_meta_end',           [ self::class, 'orderItemMeta' ], 11, 1 );

        add_action( 'bkntc_payment_confirmed_backend',          [ self::class, 'appointmentPaid' ], 10, 1 );

    }

	public static function getItemData ( $otherData, $cartItem )
	{
		$wcService = self::getWCService( $cartItem );

		if ( $wcService !== false )
		{
			$otherData[] = [
				'name'  => bkntc__( 'Appointment details' ),
				'value' => '&nbsp;</dd></dl>' . $wcService->productAdditionalData() . '<dl><dd>'
			];
		}

		return $otherData;
	}

	public static function getItemName ( $itemName, $cartItem )
	{
		$wcService = self::getWCService( $cartItem );

		if ( $wcService !== false && ! empty( $wcService->bookingData->getServiceInf()->name ) )
		{
			$itemName           = htmlspecialchars($wcService->bookingData->getServiceInf()->name);
			$appointmentsCount  = count( $wcService->bookingData->getAllRecurringAppointmentIds() );

			if ( $appointmentsCount > 1 )
			{
				$itemName .= ' <strong class="product-quantity">× ' . $appointmentsCount . '</strong>';
			}
		}

		return $itemName;
	}

	public static function getItemImage ( $productImg, $cartItem )
	{
		$wcService = self::getWCService( $cartItem );

		if ( $wcService !== false && ! empty( $wcService->bookingData->getServiceInf()->image ) )
		{
			$productImg = '<img src="' . Helper::profileImage( $wcService->bookingData->getServiceInf()->image, 'Services' ) . '" width="300" height="300">';
		}

		return $productImg;
	}

	public static function getItemPrice ( $productPrice, $cartItem, $cartItemKey )
	{
		if ( self::isBookneticItem( $cartItem ) )
		{
			$productPrice = wc_price(  $cartItem[ 'booknetic_appointment_payable_sum' ] );
		}

		return $productPrice;
	}

	public static function beforeCalculateTotals ( $cartObject )
	{
		foreach ( $cartObject->cart_contents as $cartItem )
		{
			if ( self::isBookneticItem( $cartItem ) )
			{
				$cartItem[ 'data' ]->set_price( $cartItem[ 'booknetic_appointment_payable_sum' ] );
			}
		}
	}

	public static function isBookneticItem( $cartItem )
	{
		if ( ! empty( $cartItem[ 'booknetic_appointment_id' ] ) && ! empty( self::$cartItems[ $cartItem['booknetic_appointment_id'] ] ) )
		{
			$wcService = self::$cartItems[ $cartItem[ 'booknetic_appointment_id' ] ];

			return $wcService->isAppointmentExists();
		}

		return false;
	}

	public static function getWCService( $cartItem )
	{
		return self::isBookneticItem( $cartItem ) ? self::$cartItems[ $cartItem[ 'booknetic_appointment_id' ] ] : false;
	}

	public static function checkoutCreateOrderLineItem ( $item, $cartItem_key, $values, $order )
	{
        if ( isset( $values[ 'booknetic_appointment_id' ] ) )
		{
			$item->update_meta_data( 'booknetic_appointment_id', $values[ 'booknetic_appointment_id' ] );

		}
	}

	public static function removeCartItem( $cartItemKey, $cart )
	{
		$wcService = self::getWCService( $cart->removed_cart_contents[ $cartItemKey ] );

		if ( $wcService !== false )
		{
			$wcService->removeAppointment();
		}
	}

	public static function checkoutFields ( $value, $fieldName )
	{
		if ( ! empty( self::$cartItems ) )
		{
			$wcService = reset( self::$cartItems );

			switch ( $fieldName )
			{
				case 'billing_first_name':
					return $wcService->bookingData->getCustomerInf()->first_name;
					break;
				case 'billing_last_name':
					return $wcService->bookingData->getCustomerInf()->last_name;
					break;
				case 'billing_email':
					return $wcService->bookingData->getCustomerInf()->email;
					break;
                case 'billing_phone':
                    //doit: ya butun inputlari reverse edib qaytaraq ya da '+' isharesin gondermeyek
					return !is_rtl() ? $wcService->bookingData->getCustomerInf()->phone_number : strrev($wcService->bookingData->getCustomerInf()->phone_number);
					break;
			}
		}

		return $value;
	}

	public static function orderStatusChanged ( $orderId, $from, $to )
	{
		$wcOrderStatuses = Helper::getOption( 'woocommerce_order_statuses', 'wc-processing,wc-on-hold,wc-completed', false );
		$wcOrderStatuses = explode(',', $wcOrderStatuses);

		if ( ! in_array( 'wc-' . $to, $wcOrderStatuses ) || self::$twoWaySync )
			return;

		$order = new \WC_Order( $orderId );

		foreach ( $order->get_items() as $itemId => $orderItem )
		{
			$appointmentId = wc_get_order_item_meta( $itemId, 'booknetic_appointment_id' );

            if ( ! empty( $appointmentId ) )
            {
                $appointmentInf = Appointment::get( $appointmentId );

                if ( ! empty( $appointmentInf ) && $appointmentInf->payment_status === 'pending' )
                {
                    $customerInf = Customer::get( $appointmentInf->customer_id );
                    $wpUserMetaData = false;

                    if ( ! empty( $customerInf->user_id ) )
                    {
                        //doit: returns an array with truthy value if user has not yet made a successful payment
                        $wpUserMetaData = get_user_meta( $customerInf->user_id, 'booknetic_new_wp_user' );
                    }

                    //doit: if you want to set customer id at every appointment despite being paid insert the called function to above statement
                    if ( $wpUserMetaData && $wpUserMetaData[0] ) //should be true('1') if it's the new user
                    {
                        update_post_meta( $orderId, '_customer_user', $customerInf->user_id );
                    }

                    self::$twoWaySync = true;

                    PaymentGatewayService::confirmPayment( $appointmentInf->payment_id );
                }
            }
		}
        self::performRollBackToSaaSAdmin();
	}

	public static function orderItemMeta ( $itemId )
	{
		$appointmentId = wc_get_order_item_meta( $itemId, 'booknetic_appointment_id' );

        if ( $appointmentId > 0 )
        {
            $bookingData = AppointmentSmartObject::load( $appointmentId );

            if ( $bookingData->getInfo() && $bookingData->getInfo()->id > 0 )
            {
                echo '<div><strong>' . bkntc__( 'Appointment details' ) . ':</strong></div>';
                echo WCProductObject::productAdditionalDataStatic( $bookingData );
            }
        }
	}

    //Only the God knows what's happening here...
    public static function addDynamicMetaData()
    {
        add_filter('woocommerce_order_item_get_formatted_meta_data', function( $all_metadata )
        {
            foreach ( $all_metadata AS $metadata )
            {
                if ( $metadata->key === 'booknetic_appointment_id' && is_numeric( $metadata->value ) )
                {
                    $appointmentId = $metadata->value;
                    $metadata->display_key =  bkntc__( 'Appointment ID' );

                    $bookingData = AppointmentSmartObject::load( $appointmentId );

                    if ( $bookingData->getInfo() && $bookingData->getInfo()->id > 0 )
                    {
                        $metadataFound = false;

                        foreach( $all_metadata AS $metadatum )
                        {
                            if ( $metadatum->key === 'booknetic_appointment_details' && $metadatum->value === 'booknetic_product_additional_data' )
                            {
                                $metadatum->display_key = bkntc__( 'Appointment Details' );
                                $metadatum->display_value = WCProductObject::productAdditionalDataStatic( $bookingData );

                                $metadataFound = true;

                                break;
                            }
                        }

                        if ( ! $metadataFound )
                        {
                            $all_metadata[] = (object) [
                                'key' => 'booknetic_appointment_details',
                                'value' => 'booknetic_product_additional_data',
                                'display_key' => bkntc__( 'Appointment Details' ),
                                'display_value' => WCProductObject::productAdditionalDataStatic( $bookingData )
                            ];
                        }

                        $appointmentStatus = Helper::appointmentStatus( $bookingData->getInfo()->status )[ 'title' ];
                        $metadata->display_value =  sprintf( '<p> %d ( %s )</p>', $appointmentId, $appointmentStatus );

                    }
                    else
                    {
                        $metadata->display_value =  sprintf( '<p> %d ( %s )</p>', $appointmentId, bkntc__( 'Deleted Appointment' ) );
                    }
                }
            }
            return $all_metadata;
        });
    }

    public static function appointmentPaid ( $appointmentID )
    {
        if ( is_null( $appointmentID ) || self::$twoWaySync )
            return;

        $orderID = DB::DB()->get_row(
            DB::DB()->prepare( "SELECT `order_id` FROM " . DB::DB()->prefix . "woocommerce_order_items" . " WHERE order_item_id IN ( SELECT order_item_id FROM " . DB::DB()->prefix . "woocommerce_order_itemmeta" . " WHERE `meta_key` = 'booknetic_appointment_id' AND `meta_value` = %d )", $appointmentID )
        );

        if ( isset( $orderID->order_id ) && is_numeric( $orderID->order_id ) && (int) $orderID->order_id > 0 )
        {
            $order = wc_get_order( $orderID->order_id );

            $approvedWCStatus = Helper::getOption( 'woocommerce_approved_order_status', 'bkntc_dont_change' );

            if ( $approvedWCStatus === 'bkntc_dont_change' || ! array_key_exists( $approvedWCStatus, wc_get_order_statuses() ) )
                return;

            $approvedWCStatus = str_replace( 'wc-', '', $approvedWCStatus );

            foreach ( $order->get_items() as $itemId => $orderItem )
            {
                $appointmentPaid = false;

                $orderAppointmentId = wc_get_order_item_meta( $itemId, 'booknetic_appointment_id' );

                if ( ! empty( $orderAppointmentId ) )
                {
                    $appointmentInf = Appointment::get($orderAppointmentId);
                }

                if ( ! empty( $appointmentInf ) && $appointmentInf->payment_status === 'paid' )
                {
                    $appointmentPaid = true;
                }
            }

            if ( $appointmentPaid && ! $order->has_status( $approvedWCStatus ) )
            {
                self::$twoWaySync = true;

                $order->update_status( $approvedWCStatus );
            }
        }
    }

	public static function checkoutCartItemQuantity ( $quantity, $item )
	{
		if ( isset( $item[ 'booknetic_appointment_id' ] ) )
		{
			$quantity = '';
		}

		return $quantity;
	}

	public static function displayItemMeta ( $html, $item, $args )
	{
		if ( isset( $item[ 'booknetic_appointment_id' ] ) )
		{
			$html = '';
		}

		return $html;
	}

	public static function thankYouPageItemName ( $item_name, $item )
	{
		if( ! empty( $item['booknetic_appointment_id']) )
		{
            self::unsetCustomerCookie();

			$appointmentsCustomerObj = AppointmentSmartObject::load( $item['booknetic_appointment_id'], true );
			$serviceInf = $appointmentsCustomerObj->getServiceInf();
			if( is_object( $serviceInf ) )
			{
				$item_name = $serviceInf->name;
			}
			$appointmentsCount  = count( $appointmentsCustomerObj->getAllRecurringAppointmentIds() );

			if ( $appointmentsCount > 1 )
			{
				$item_name .= ' <strong class="product-quantity">× ' . $appointmentsCount . '</strong>';
			}
		}

		return $item_name;
	}


	public static function emptyCart ()
	{
		foreach ( self::$cartItems as $item )
		{
			if ( $item->isAppointmentExists() && ! $item->isAppointmentPaid() )
			{
				$item->removeAppointment();
			}
		}
	}

	public static function bookneticProduct ()
	{
		if ( ! PaymentGatewayService::find( 'woocommerce' )->isEnabled() )
		{
			return 0;
		}

		$productId = Helper::getOption( 'woocommerce_product_id', null, false );

		if ( $productId )
		{
			$productInf = wc_get_product( $productId );
		}

		if ( ! $productId || ! $productInf || ! $productInf->exists() || $productInf->get_status() !== 'publish' )
		{
			$productId = wp_insert_post( [
				'post_title'  => 'Booknetic',
				'post_type'   => 'product',
				'post_status' => 'publish'
			] );

			Helper::setOption( 'woocommerce_product_id', $productId, false );

			// set product is simple/variable/grouped
			wp_set_object_terms( $productId, 'simple', 'product_type' );

			update_post_meta( $productId, '_visibility', 'hidden' );
			update_post_meta( $productId, '_stock_status', 'instock' );
			update_post_meta( $productId, 'total_sales', '0' );
			update_post_meta( $productId, '_downloadable', 'no' );
			update_post_meta( $productId, '_virtual', 'yes' );
			update_post_meta( $productId, '_regular_price', '0' );
			update_post_meta( $productId, '_sale_price', '' );
			update_post_meta( $productId, '_purchase_note', '' );
			update_post_meta( $productId, '_featured', 'no' );
			update_post_meta( $productId, '_weight', '' );
			update_post_meta( $productId, '_length', '' );
			update_post_meta( $productId, '_width', '' );
			update_post_meta( $productId, '_height', '' );
			update_post_meta( $productId, '_sku', '' );
			update_post_meta( $productId, '_product_attributes', [] );
			update_post_meta( $productId, '_sale_price_dates_from', '' );
			update_post_meta( $productId, '_sale_price_dates_to', '' );
			update_post_meta( $productId, '_price', '0' );
			update_post_meta( $productId, '_sold_individually', 'yes' );
			update_post_meta( $productId, '_manage_stock', 'no' );
			update_post_meta( $productId, '_backorders', 'no' );
			wc_update_product_stock( $productId, 0, 'set' );
			update_post_meta( $productId, '_stock', '' );
		}

		return $productId;
	}

	private static function addToCart ( $appointmentObj )
	{
	    $appointmentId = $appointmentObj->getFirstAppointmentId();
		self::setCustomerCookie();
		WC()->cart->add_to_cart( self::bookneticProduct(), 1, '', [], [
			'booknetic_appointment_id'          => $appointmentId,
			'booknetic_appointment_payable_sum' => $appointmentObj->getPayableToday( true ),
			'client_time_zone'                  => Helper::_post( 'client_time_zone', '', 'string' )
		] );

		setcookie( 'booknetic_tenant_id', Permission::tenantId(), time() + 24 * 60 * 60, COOKIEPATH, COOKIE_DOMAIN );
	}

	/**
	 * Set WC Customer session cookie
	 *
	 * @return bool
	 */
	private static function setCustomerCookie ()
	{
		if ( WC()->session && WC()->session instanceof \WC_Session_Handler && WC()->session->get_session_cookie() === false )
		{
			WC()->session->set_customer_session_cookie( true );
		}
	}

	private static function unsetCustomerCookie()
	{
		if ( WC()->session && WC()->session instanceof \WC_Session_Handler && WC()->session->get_session_cookie() !== false )
		{
			WC()->session->forget_session();
		}
	}

	/**
	 * Get WooCommerce Cart URL
	 *
	 * @return string
	 */
	private static function redirect ()
	{
		return Helper::getOption( 'woocommerce_rediret_to', 'cart', false ) === 'cart' ? wc_get_cart_url() : wc_get_checkout_url();
	}

	private static function setClientTimezone ( $cartItems )
	{
		if ( Helper::_post( 'client_time_zone', null ) === null )
		{
			foreach ( $cartItems as $item )
			{
				if ( isset( $item[ 'client_time_zone' ] ) && $item[ 'client_time_zone' ] !== '' )
				{
					Date::resetTimezone();

					$_POST[ 'client_time_zone' ] = (string) $item[ 'client_time_zone' ];

					return;
				}
			}
		}
	}

    public static function handleActionsAsTenant()
    {
        $action = Helper::_post( 'action', '' , 'string' );
        $orderId = Helper::_post( 'post_ID', '', 'int' );
        $postType = Helper::_post( 'post_type', '', 'string' );
        $update = Helper::_post( 'save', '', 'string' );
        $new_status = Helper::_post( 'order_status', '', 'string' );

        if ( $action !== 'editpost' || $update !== 'Update' || $postType !== 'shop_order' || empty( $new_status ) || empty( $orderId ) )
            return;

        $wcOrderStatuses = Helper::getOption( 'woocommerce_order_statuses', 'wc-processing,wc-on-hold,wc-completed', false );
        $wcOrderStatuses = explode(',', $wcOrderStatuses);

        if ( ! in_array( $new_status, $wcOrderStatuses ) )
            return;

        $order = new \WC_Order( $orderId );

        foreach ( $order->get_items() as $itemId => $orderItem )
        {
            $appointmentID = wc_get_order_item_meta( $itemId, 'booknetic_appointment_id' );

            $appointmentInf = Appointment::noTenant()->get( $appointmentID );

            if ( ! empty( $appointmentInf ) && $appointmentInf->payment_status === 'pending' && ! is_null( $appointmentInf->tenant_id ) && is_numeric( $appointmentInf->tenant_id ) && $appointmentInf->tenant_id > 0 )
            {
                Permission::setTenantId( $appointmentInf->tenant_id );
                return;
            }
        }
    }

    public static function performRollBackToSaaSAdmin()
    {
        //todo: also check Permission::isBackend()...
        if ( ! ( Helper::isSaaSVersion() && Permission::isSuperAdministrator() ) )
            return;

        if ( Permission::tenantId() > 0 )
        {
            Permission::setTenantId( -1 );
        }
    }

}
