<?php

namespace BookneticAddon\WCPaymentGateway;

use BookneticAddon\WCPaymentGateway\Providers\WcMultiTenantHelper;
use BookneticApp\Backend\Appointments\Helpers\AppointmentRequestData;
use BookneticApp\Backend\Appointments\Helpers\AppointmentRequests;
use BookneticApp\Providers\Core\Permission;
use BookneticApp\Providers\UI\TabUI;
use BookneticApp\Providers\Core\Route;
use BookneticApp\Providers\Helpers\Helper;
use BookneticApp\Providers\Core\AddonLoader;
use BookneticApp\Providers\Core\Capabilities;
use BookneticAddon\WCPaymentGateway\Backend\Ajax;
use BookneticSaaS\Providers\Core\Route as SaaSRoute;
use BookneticAddon\WCPaymentGateway\Providers\WooCommerceGateway;
use BookneticSaaS\Providers\UI\SettingsMenuUI as SaaSSettingsMenuUI;
use BookneticAddon\WCPaymentGateway\Backend\Controller;

function bkntc__ ( $text, $params = [], $esc = true )
{
    return \bkntc__( $text, $params, $esc, WcPaymentGatewayAddon::getAddonSlug() );
}

class WcPaymentGatewayAddon extends AddonLoader
{

	public function __construct()
	{
		parent::__construct();

		if( Helper::isSaaSVersion() )
		{
			/* Bezi WC Payment Gatewaylerde get_option() init`den kenarda chagirilir deye mecbur bu methodu da init`den kenarda chagiririg ki, filter elave ede bilsin */
			$module = Route::getCurrentModule();
			$action = Route::getCurrentAction();

			if ( ( $module == 'wcpaymentgateway' && $action == 'woocommerce_gateway_settings' ) || ( $module == 'settings' && $action == 'payment_gateways_settings' ))
			{
				WcMultiTenantHelper::getInstance()->startReplacingNecessaryOptions();
			}
		}
	}

	public function init ()
    {
        if ( ! class_exists( 'woocommerce' ) )
        {
            return;
        }

        Capabilities::registerTenantCapability( 'woocommerce', bkntc__( 'WooCommerce integration' ) );

        if ( ! Capabilities::tenantCan( 'woocommerce' ) )
            return;

        Capabilities::register( 'woocommerce_settings', bkntc__( 'WooCommerce payment gateways settings' ), 'settings' );

        add_action( 'bkntc_booking_step_confirmation_validation', [ $this, 'emptyCartOnConfirm' ] );

        WooCommerceGateway::load();
    }

    public function initBackend ()
    {
        if ( ! class_exists( 'woocommerce' ) || ! Capabilities::tenantCan( 'woocommerce' ) )
        {
            return;
        }

        if ( Capabilities::userCan( 'woocommerce_settings' ) )
        {
            Route::post( 'wcpaymentgateway', Ajax::class );
	        Route::get( 'wcpaymentgateway', Controller::class );

	        if ( ! Helper::isSaaSVersion() || Helper::getOption('allow_to_use_woocommerce_integration', 'off', false) === 'on' )
            {
                TabUI::get( 'payment_gateways_settings' )
                    ->item( 'woocommerce' )
                    ->setTitle( Helper::isSaaSVersion() ? bkntc__( 'Others' ) : bkntc__( 'Woocommerce' ) )
                    ->addView( __DIR__ . '/Backend/view/settings.php' );
            }

            add_filter( 'bkntc_after_request_settings_save_payment_gateways_settings', [ Listener::class, 'saveSettings' ] );
            add_action( 'bkntc_enqueue_assets', [ self::class, 'enqueueAssets' ], 10, 2 );


        }
    }

    public function initFrontend ()
    {
        if ( ! class_exists( 'woocommerce' ) || ! Capabilities::tenantCan( 'woocommerce' ) )
        {
            return;
        }

        add_action('bkntc_after_booking_panel_shortcode', function ()
        {
            wp_enqueue_script( 'booknetic-woocommerce-init', WcPaymentGatewayAddon::loadAsset( 'assets/frontend/js/woocommerce.js' ), [ 'booknetic' ] );
        });

        add_filter( 'bkntc_after_frontend_request_get_data_confirm_details', [ Listener::class, 'addParamsToConfirmDetails' ] );
        add_filter('bkntc_frontend_localization',function ($localization){
            $localization['automatically_redirecting_to_order_page'] = bkntc__('Please wait, You are automatically redirecting to order page...');
            return $localization;
        });
    }

    // doit: burda ne bas verir ??
    public function emptyCartOnConfirm ()
    {
        if ( AppointmentRequests::self()->getPaymentMethod() === 'woocommerce' )
        {
            WooCommerceGateway::emptyCart();
            foreach ( AppointmentRequests::appointments() as $appointment )
            {
                $appointment->timeslots = null;
            }
        }
    }

    public static function enqueueAssets ( $module, $action )
    {
        if ( $module == 'settings' && $action == 'payment_gateways_settings' )
        {
            if ( Helper::isSaaSVersion() ) // is tenant
            {
                echo '<script type="application/javascript" src="' . self::loadAsset( 'assets/backend/js/woocommerce-settings-tenant.js' ) . '"></script>';
            }
            else // is regular
            {
                echo '<script type="application/javascript" src="' . self::loadAsset( 'assets/backend/js/woocommerce-settings.js' ) . '"></script>';
            }

            echo '<link rel="stylesheet" href="' . self::loadAsset( 'assets/backend/css/woocommerce-settings.css' ) . '">';
        }
    }

    public function initSaaSBackend ()
    {
        if ( ! class_exists( 'woocommerce' ) )
        {
            return;
        }

        SaaSRoute::post( 'wcpaymentgateway', Ajax::class );

        SaaSSettingsMenuUI::get( 'woocommerce_settings', 'wcpaymentgateway' )
                          ->setTitle( bkntc__( 'WooCommerce settings' ) )
                          ->setDescription( bkntc__( 'You can change settings for WooCommerce integration from here.' ) )
                          ->setIcon( WcPaymentGatewayAddon::loadAsset( 'assets/backend/icons/woocommerce-settings.svg' ) )
                          ->setPriority( 15 );
    }

}